===================
django-adminfilters
===================

Collection of extra filters for the django admin site


Filters
=======

* ForeignKeyComboFilter
* FlatComboFilter
* DateRangeFilter
* IntegerRangeFilter
* CheckBoxFilter
* MultiValuesFilter



Project links
-------------

* Project home page: https://github.com/saxix/django-adminfilters
* Download: http://pypi.python.org/pypi/django-adminfilters/
